==> jc-1.4.0.tar.gz: javax/xml/datatype/DatatypeConstants__24Field.c <==
// public final class javax.xml.datatype.DatatypeConstants$Field

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3e0da72887676f79 javax_xml_datatype_DatatypeConstants
// @dep_class e879b1dd8099eab0 javax_xml_datatype_DatatypeConstants__24Field

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_datatype_DatatypeConstants
// @dep_header javax_xml_datatype_DatatypeConstants__24Field

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/datatype/DatatypeConstants.h"
#include "javax/xml/datatype/DatatypeConstants__24Field.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final int id
static _jc_field _jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$id = {
	.name=		"id",
	.signature=	"I",
	.class=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_xml_datatype_DatatypeConstants__24Field$object, nonrefs.javax_xml_datatype_DatatypeConstants__24Field.id),
};

// final java.lang.String name
static _jc_field _jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_xml_datatype_DatatypeConstants__24Field$object, refs[-1].javax_xml_datatype_DatatypeConstants__24Field.name),
};

// Fields
static _jc_field *const _jc_javax_xml_datatype_DatatypeConstants__24Field$fields[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$name,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$id
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(int, java.lang.String)
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$_init$206934d97c5ba451[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$_init$206934d97c5ba451[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$param_types$_init$206934d97c5ba451[] = {
	&_jc_int$prim$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$_init$206934d97c5ba451 = {
	.name=			"<init>",
	.signature=		"(ILjava/lang/String;)V",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.param_types=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_types$_init$206934d97c5ba451,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$_init$206934d97c5ba451,
	.signature_hash=	_JC_JLONG(0x206934d97c5ba451),
	.access_flags=		0,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$_init$206934d97c5ba451
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, _init$206934d97c5ba451);

void
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this, jint param0, _jc_java_lang_String$object *param1)
{
	jint i0;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	i0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(63);				// 0
	_JC_PRIM_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, id) = i0;
	_JC_LINE_NUMBER(64);				// 1
	_JC_REF_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, name) = r1;
	_JC_LINE_NUMBER(65);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int getId()
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$getId$d8363e0f5dfda08c[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$getId$d8363e0f5dfda08c[] = { 
_JC_TYPE_INT };

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c = {
	.name=			"getId",
	.signature=		"()I",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$getId$d8363e0f5dfda08c,
	.signature_hash=	_JC_JLONG(0xd8363e0f5dfda08c),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable, javax_xml_datatype_DatatypeConstants__24Field.getId$d8363e0f5dfda08c) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$getId$d8363e0f5dfda08c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, getId$d8363e0f5dfda08c);

jint
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this)
{
	jint i0;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(69);				// 0
	i0 = _JC_PRIM_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, id);
	return i0;
}

//
// public final java.lang.String toString()
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable, javax_xml_datatype_DatatypeConstants__24Field.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this)
{
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_xml_datatype_DatatypeConstants__24Field$methods[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$_init$206934d97c5ba451,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_48[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[48]=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_48,
	[113]=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/xml/datatype/DatatypeConstants",	_JC_JLONG(0x3e0da72887676f79) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype _jc_javax_xml_datatype_DatatypeConstants__24Field$type = {
    .type= {
	.name=			"javax/xml/datatype/DatatypeConstants$Field",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xe879b1dd8099eab0),
		.source_file=		"DatatypeConstants.java",
		.instance_size=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$refs) + sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$fields) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$fields),
		.fields=		_jc_javax_xml_datatype_DatatypeConstants__24Field$fields,
		.num_methods=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$methods) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$methods),
		.methods=		_jc_javax_xml_datatype_DatatypeConstants__24Field$methods,
		.instanceof_hash_table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_table,
		.outer_class=		&_jc_javax_xml_datatype_DatatypeConstants$type,
		.num_class_depends=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends),
		.class_depends=		_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_xml_datatype_DatatypeConstants__24Field= {
	    .getId$d8363e0f5dfda08c=
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c,
	    .toString$7ea43b33b80a3070=
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/xml/datatype/DatatypeConstants__24Field.c <==
// public final class javax.xml.datatype.DatatypeConstants$Field

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3e0da72887676f79 javax_xml_datatype_DatatypeConstants
// @dep_class e879b1dd8099eab0 javax_xml_datatype_DatatypeConstants__24Field

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_xml_datatype_DatatypeConstants
// @dep_header javax_xml_datatype_DatatypeConstants__24Field

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/xml/datatype/DatatypeConstants.h"
#include "javax/xml/datatype/DatatypeConstants__24Field.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final int id
static _jc_field _jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$id = {
	.name=		"id",
	.signature=	"I",
	.class=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_xml_datatype_DatatypeConstants__24Field$object, nonrefs.javax_xml_datatype_DatatypeConstants__24Field.id),
};

// final java.lang.String name
static _jc_field _jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_xml_datatype_DatatypeConstants__24Field$object, refs[-1].javax_xml_datatype_DatatypeConstants__24Field.name),
};

// Fields
static _jc_field *const _jc_javax_xml_datatype_DatatypeConstants__24Field$fields[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$name,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$field_info$id
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(int, java.lang.String)
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$_init$206934d97c5ba451[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$_init$206934d97c5ba451[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$param_types$_init$206934d97c5ba451[] = {
	&_jc_int$prim$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$_init$206934d97c5ba451 = {
	.name=			"<init>",
	.signature=		"(ILjava/lang/String;)V",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.param_types=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_types$_init$206934d97c5ba451,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$_init$206934d97c5ba451,
	.signature_hash=	_JC_JLONG(0x206934d97c5ba451),
	.access_flags=		0,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$_init$206934d97c5ba451
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, _init$206934d97c5ba451);

void _JC_JCNI_ATTR
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$_init$206934d97c5ba451(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this, jint param0, _jc_java_lang_String$object *param1)
{
	jint i0;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	i0 = param0;
	r1 = param1;
	_JC_LINE_NUMBER(63);				// 0
	_JC_PRIM_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, id) = i0;
	_JC_LINE_NUMBER(64);				// 1
	_JC_REF_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, name) = r1;
	_JC_LINE_NUMBER(65);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int getId()
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$getId$d8363e0f5dfda08c[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$getId$d8363e0f5dfda08c[] = { 
_JC_TYPE_INT };

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c = {
	.name=			"getId",
	.signature=		"()I",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$getId$d8363e0f5dfda08c,
	.signature_hash=	_JC_JLONG(0xd8363e0f5dfda08c),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable, javax_xml_datatype_DatatypeConstants__24Field.getId$d8363e0f5dfda08c) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$getId$d8363e0f5dfda08c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, getId$d8363e0f5dfda08c);

jint _JC_JCNI_ATTR
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this)
{
	jint i0;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(69);				// 0
	i0 = _JC_PRIM_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, id);
	return i0;
}

//
// public final java.lang.String toString()
//

static _jc_linenum _jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_xml_datatype_DatatypeConstants__24Field$vtable, javax_xml_datatype_DatatypeConstants__24Field.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_xml_datatype_DatatypeConstants__24Field, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_xml_datatype_DatatypeConstants__24Field$object *this)
{
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_xml_datatype_DatatypeConstants__24Field, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_xml_datatype_DatatypeConstants__24Field$methods[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$_init$206934d97c5ba451,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$getId$d8363e0f5dfda08c,
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_48[] = {
	&_jc_javax_xml_datatype_DatatypeConstants__24Field$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[48]=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_48,
	[101]=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/xml/datatype/DatatypeConstants",	_JC_JLONG(0x3e0da72887676f79) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_xml_datatype_DatatypeConstants__24Field$vtype _jc_javax_xml_datatype_DatatypeConstants__24Field$type = {
    .type= {
	.name=			"javax/xml/datatype/DatatypeConstants$Field",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xe879b1dd8099eab0),
		.source_file=		"DatatypeConstants.java",
		.instance_size=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$refs) + sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$fields) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$fields),
		.fields=		_jc_javax_xml_datatype_DatatypeConstants__24Field$fields,
		.num_methods=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$methods) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$methods),
		.methods=		_jc_javax_xml_datatype_DatatypeConstants__24Field$methods,
		.instanceof_hash_table=	_jc_javax_xml_datatype_DatatypeConstants__24Field$instanceof_hash_table,
		.outer_class=		&_jc_javax_xml_datatype_DatatypeConstants$type,
		.num_class_depends=		sizeof(_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends) / sizeof(*_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends),
		.class_depends=		_jc_javax_xml_datatype_DatatypeConstants__24Field$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_xml_datatype_DatatypeConstants__24Field= {
	    .getId$d8363e0f5dfda08c=
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$getId$d8363e0f5dfda08c,
	    .toString$7ea43b33b80a3070=
		&_jc_javax_xml_datatype_DatatypeConstants__24Field$method$toString$7ea43b33b80a3070,
	},
    }
};
